diff --git a/applications/solvers/multiphase/multiphaseInterFoam/Make/files b/applications/solvers/multiphase/multiphaseInterFoam/Make/files
index 0204e6cabf9b31dfb9fd1d6c1985a1759f16908f..4820de61a553d6ea05ce5e7acc09c7fdaf36737f 100644
--- a/applications/solvers/multiphase/multiphaseInterFoam/Make/files
+++ b/applications/solvers/multiphase/multiphaseInterFoam/Make/files
@@ -1,5 +1,5 @@
 multiphaseMixture/phase/phase.C
-multiphaseMixture/alphaContactAngle/alphaContactAngleFvPatchScalarField.C
+multiphaseMixture/multiphaseAlphaContactAngle/multiphaseAlphaContactAngleFvPatchScalarField.C
 multiphaseMixture/multiphaseMixture.C
 multiphaseInterFoam.C
 
diff --git a/applications/solvers/multiphase/multiphaseInterFoam/Make/options b/applications/solvers/multiphase/multiphaseInterFoam/Make/options
index 1fc821726c9c4e0e9710d90f77a366ec7d7519fb..6e9363f13f8c2a2553afadfb7a61600a1d8ebf39 100644
--- a/applications/solvers/multiphase/multiphaseInterFoam/Make/options
+++ b/applications/solvers/multiphase/multiphaseInterFoam/Make/options
@@ -2,17 +2,15 @@ EXE_INC = \
     -I../interFoam \
     -ImultiphaseMixture \
     -ImultiphaseMixture/phase \
-    -ImultiphaseMixture/alphaContactAngle \
+    -ImultiphaseMixture/multiphaseAlphaContactAngle \
     -I$(LIB_SRC)/transportModels \
     -I$(LIB_SRC)/transportModels/incompressible/lnInclude \
-    -I$(LIB_SRC)/transportModels/interfaceProperties/lnInclude \
     -I$(LIB_SRC)/turbulenceModels/incompressible/turbulenceModel \
     -I$(LIB_SRC)/finiteVolume/lnInclude
 
 EXE_LIBS = \
     -linterfaceProperties \
     -lincompressibleTransportModels \
-    -lincompressibleTransportModels \
     -lincompressibleRASModels \
     -lincompressibleLESModels \
-    -lfiniteVolume
+    -lfiniteVolume
\ No newline at end of file
diff --git a/applications/solvers/multiphase/multiphaseInterFoam/createFields.H b/applications/solvers/multiphase/multiphaseInterFoam/createFields.H
index fb6449629402a36f340e711e6ef89d7b64da8d96..6ef68821969fae9ec3e0009b25aed4e1c772c567 100644
--- a/applications/solvers/multiphase/multiphaseInterFoam/createFields.H
+++ b/applications/solvers/multiphase/multiphaseInterFoam/createFields.H
@@ -26,7 +26,7 @@
         mesh
     );
 
-#   include "createPhi.H"
+    #include "createPhi.H"
 
     multiphaseMixture mixture(U, phi);
 
diff --git a/applications/solvers/multiphase/multiphaseInterFoam/multiphaseInterFoam.C b/applications/solvers/multiphase/multiphaseInterFoam/multiphaseInterFoam.C
index 1a5bed606d5563a9013816b5a734c5082e8163dd..546e635346773d8b6fcfcb4ef8eb1ec868df5309 100644
--- a/applications/solvers/multiphase/multiphaseInterFoam/multiphaseInterFoam.C
+++ b/applications/solvers/multiphase/multiphaseInterFoam/multiphaseInterFoam.C
@@ -80,7 +80,7 @@ int main(int argc, char *argv[])
 
         #include "continuityErrs.H"
 
-        turbulence->correct();
+        //turbulence->correct();
 
         runTime.write();
 
diff --git a/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/alphaContactAngle/alphaContactAngleFvPatchScalarField.C b/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/multiphaseAlphaContactAngle/multiphaseAlphaContactAngleFvPatchScalarField.C
similarity index 76%
rename from applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/alphaContactAngle/alphaContactAngleFvPatchScalarField.C
rename to applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/multiphaseAlphaContactAngle/multiphaseAlphaContactAngleFvPatchScalarField.C
index 3cf76bab1b0002e7f7ae900eac6eeb6318d05616..9cc9b7ed07d29a2dee736e4e0f96b336d15e59bf 100644
--- a/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/alphaContactAngle/alphaContactAngleFvPatchScalarField.C
+++ b/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/multiphaseAlphaContactAngle/multiphaseAlphaContactAngleFvPatchScalarField.C
@@ -23,7 +23,7 @@ License
 
 \*---------------------------------------------------------------------------*/
 
-#include "alphaContactAngleFvPatchScalarField.H"
+#include "multiphaseAlphaContactAngleFvPatchScalarField.H"
 #include "addToRunTimeSelectionTable.H"
 #include "fvPatchFieldMapper.H"
 
@@ -32,7 +32,8 @@ License
 namespace Foam
 {
 
-alphaContactAngleFvPatchScalarField::interfaceThetaProps::interfaceThetaProps
+multiphaseAlphaContactAngleFvPatchScalarField::interfaceThetaProps::
+interfaceThetaProps
 (
     Istream& is
 )
@@ -47,7 +48,7 @@ alphaContactAngleFvPatchScalarField::interfaceThetaProps::interfaceThetaProps
 Istream& operator>>
 (
     Istream& is,
-    alphaContactAngleFvPatchScalarField::interfaceThetaProps& tp
+    multiphaseAlphaContactAngleFvPatchScalarField::interfaceThetaProps& tp
 )
 {
     is  >> tp.theta0_ >> tp.uTheta_ >> tp.thetaA_ >> tp.thetaR_;
@@ -58,7 +59,7 @@ Istream& operator>>
 Ostream& operator<<
 (
     Ostream& os,
-    const alphaContactAngleFvPatchScalarField::interfaceThetaProps& tp
+    const multiphaseAlphaContactAngleFvPatchScalarField::interfaceThetaProps& tp
 )
 {
     os  << tp.theta0_ << token::SPACE
@@ -72,7 +73,8 @@ Ostream& operator<<
 
 // * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //
 
-alphaContactAngleFvPatchScalarField::alphaContactAngleFvPatchScalarField
+multiphaseAlphaContactAngleFvPatchScalarField::
+multiphaseAlphaContactAngleFvPatchScalarField
 (
     const fvPatch& p,
     const DimensionedField<scalar, volMesh>& iF
@@ -82,9 +84,10 @@ alphaContactAngleFvPatchScalarField::alphaContactAngleFvPatchScalarField
 {}
 
 
-alphaContactAngleFvPatchScalarField::alphaContactAngleFvPatchScalarField
+multiphaseAlphaContactAngleFvPatchScalarField::
+multiphaseAlphaContactAngleFvPatchScalarField
 (
-    const alphaContactAngleFvPatchScalarField& gcpsf,
+    const multiphaseAlphaContactAngleFvPatchScalarField& gcpsf,
     const fvPatch& p,
     const DimensionedField<scalar, volMesh>& iF,
     const fvPatchFieldMapper& mapper
@@ -95,7 +98,8 @@ alphaContactAngleFvPatchScalarField::alphaContactAngleFvPatchScalarField
 {}
 
 
-alphaContactAngleFvPatchScalarField::alphaContactAngleFvPatchScalarField
+multiphaseAlphaContactAngleFvPatchScalarField::
+multiphaseAlphaContactAngleFvPatchScalarField
 (
     const fvPatch& p,
     const DimensionedField<scalar, volMesh>& iF,
@@ -109,9 +113,10 @@ alphaContactAngleFvPatchScalarField::alphaContactAngleFvPatchScalarField
 }
 
 
-alphaContactAngleFvPatchScalarField::alphaContactAngleFvPatchScalarField
+multiphaseAlphaContactAngleFvPatchScalarField::
+multiphaseAlphaContactAngleFvPatchScalarField
 (
-    const alphaContactAngleFvPatchScalarField& gcpsf,
+    const multiphaseAlphaContactAngleFvPatchScalarField& gcpsf,
     const DimensionedField<scalar, volMesh>& iF
 )
 :
@@ -122,7 +127,7 @@ alphaContactAngleFvPatchScalarField::alphaContactAngleFvPatchScalarField
 
 // * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //
 
-void alphaContactAngleFvPatchScalarField::write(Ostream& os) const
+void multiphaseAlphaContactAngleFvPatchScalarField::write(Ostream& os) const
 {
     fvPatchScalarField::write(os);
     os.writeKeyword("thetaProperties")
@@ -133,7 +138,7 @@ void alphaContactAngleFvPatchScalarField::write(Ostream& os) const
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
-makePatchTypeField(fvPatchScalarField, alphaContactAngleFvPatchScalarField);
+makePatchTypeField(fvPatchScalarField, multiphaseAlphaContactAngleFvPatchScalarField);
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
diff --git a/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/multiphaseMixture.C b/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/multiphaseMixture.C
index 7af947d4a71b9b68dc2c83d5a3fdab461b4fbb3d..c6dba40e138e330e833d6236b78a58c11a1a2ddd 100644
--- a/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/multiphaseMixture.C
+++ b/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/multiphaseMixture.C
@@ -24,7 +24,7 @@ License
 \*---------------------------------------------------------------------------*/
 
 #include "multiphaseMixture.H"
-#include "alphaContactAngleFvPatchScalarField.H"
+#include "multiphaseAlphaContactAngleFvPatchScalarField.H"
 #include "Time.H"
 #include "subCycle.H"
 #include "fvCFD.H"
@@ -351,10 +351,11 @@ void Foam::multiphaseMixture::correctContactAngle
 
     forAll(boundary, patchi)
     {
-        if (isA<alphaContactAngleFvPatchScalarField>(gbf[patchi]))
+        if (isA<multiphaseAlphaContactAngleFvPatchScalarField>(gbf[patchi]))
         {
-            const alphaContactAngleFvPatchScalarField& acap =
-                refCast<const alphaContactAngleFvPatchScalarField>(gbf[patchi]);
+            const multiphaseAlphaContactAngleFvPatchScalarField& acap =
+                refCast<const multiphaseAlphaContactAngleFvPatchScalarField>
+                (gbf[patchi]);
 
             vectorField& nHatPatch = nHatb[patchi];
 
@@ -362,7 +363,7 @@ void Foam::multiphaseMixture::correctContactAngle
                 mesh_.Sf().boundaryField()[patchi]
                /mesh_.magSf().boundaryField()[patchi];
 
-            alphaContactAngleFvPatchScalarField::thetaPropsTable::
+            multiphaseAlphaContactAngleFvPatchScalarField::thetaPropsTable::
                 const_iterator tp =
                 acap.thetaProps().find(interfacePair(alpha1, alpha2));
 
diff --git a/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/multiphaseMixture.H b/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/multiphaseMixture.H
index 1d94d47e915cebd30ada7bed7450aae92a502757..2a430da5b267ab852ca6904370f4a3272c136a7a 100644
--- a/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/multiphaseMixture.H
+++ b/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/multiphaseMixture.H
@@ -210,7 +210,7 @@ public:
 
 
     //- Destructor
-    ~multiphaseMixture()
+    virtual ~multiphaseMixture()
     {}
diff --git a/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/alphaContactAngle/alphaContactAngleFvPatchScalarField.H b/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/multiphaseAlphaContactAngle/multiphaseAlphaContactAngleFvPatchScalarField.H
similarity index 84%
rename from applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/alphaContactAngle/alphaContactAngleFvPatchScalarField.H
rename to applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/multiphaseAlphaContactAngle/multiphaseAlphaContactAngleFvPatchScalarField.H
index 322d0975264d6a11bfefae2c54b3bfc9f6f13500..ccbb146abb2c39c1df7c776809748480e0f1d16a 100644
--- a/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/alphaContactAngle/alphaContactAngleFvPatchScalarField.H
+++ b/applications/solvers/multiphase/multiphaseInterFoam/multiphaseMixture/multiphaseAlphaContactAngle/multiphaseAlphaContactAngleFvPatchScalarField.H
@@ -22,19 +22,19 @@ License
     along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.
 
 Class
-    Foam::alphaContactAngleFvPatchScalarField
+    Foam::multiphaseAlphaContactAngleFvPatchScalarField
 
 Description
     Contact-angle boundary condition for multi-phase interface-capturing
     simulations.  Used in conjuction with multiphaseMixture.
 
 SourceFiles
-    alphaContactAngleFvPatchScalarField.C
+    multiphaseAlphaContactAngleFvPatchScalarField.C
 
 \*---------------------------------------------------------------------------*/
 
-#ifndef alphaContactAngleFvPatchScalarField_H
-#define alphaContactAngleFvPatchScalarField_H
+#ifndef multiphaseAlphaContactAngleFvPatchScalarField_H
+#define multiphaseAlphaContactAngleFvPatchScalarField_H
 
 #include "zeroGradientFvPatchFields.H"
 #include "multiphaseMixture.H"
@@ -45,10 +45,10 @@ namespace Foam
 {
 
 /*---------------------------------------------------------------------------*\
-                           Class alphaContactAngleFvPatch Declaration
+                           Class multiphaseAlphaContactAngleFvPatch Declaration
 \*---------------------------------------------------------------------------*/
 
-class alphaContactAngleFvPatchScalarField
+class multiphaseAlphaContactAngleFvPatchScalarField
 :
     public zeroGradientFvPatchScalarField
 {
@@ -132,31 +132,31 @@ private:
 public:
 
     //- Runtime type information
-    TypeName("alphaContactAngle");
+    TypeName("multiphaseAlphaContactAngle");
 
 
     // Constructors
 
         //- Construct from patch and internal field
-        alphaContactAngleFvPatchScalarField
+        multiphaseAlphaContactAngleFvPatchScalarField
         (
             const fvPatch&,
             const DimensionedField<scalar, volMesh>&
         );
 
         //- Construct from patch, internal field and dictionary
-        alphaContactAngleFvPatchScalarField
+        multiphaseAlphaContactAngleFvPatchScalarField
         (
             const fvPatch&,
             const DimensionedField<scalar, volMesh>&,
             const dictionary&
         );
 
         //- Construct by mapping given alphaContactAngleFvPatchScalarField
         //  onto a new patch
-        alphaContactAngleFvPatchScalarField
+        multiphaseAlphaContactAngleFvPatchScalarField
         (
-            const alphaContactAngleFvPatchScalarField&,
+            const multiphaseAlphaContactAngleFvPatchScalarField&,
             const fvPatch&,
             const DimensionedField<scalar, volMesh>&,
             const fvPatchFieldMapper&
@@ -167,14 +167,14 @@ public:
         {
             return tmp<fvPatchScalarField>
             (
-                new alphaContactAngleFvPatchScalarField(*this)
+                new multiphaseAlphaContactAngleFvPatchScalarField(*this)
             );
         }
 
         //- Construct as copy setting internal field reference
-        alphaContactAngleFvPatchScalarField
+        multiphaseAlphaContactAngleFvPatchScalarField
         (
-            const alphaContactAngleFvPatchScalarField&,
+            const multiphaseAlphaContactAngleFvPatchScalarField&,
             const DimensionedField<scalar, volMesh>&
         );
 
@@ -186,7 +186,7 @@ public:
         {
             return tmp<fvPatchScalarField>
             (
-                new alphaContactAngleFvPatchScalarField(*this, iF)
+                new multiphaseAlphaContactAngleFvPatchScalarField(*this, iF)
             );
         }
 
@@ -132,31 +132,31 @@ private:
         );
 
-        //- Construct by mapping given alphaContactAngleFvPatchScalarField
+        //- Construct by mapping given multiphaseAlphaContactAngleFvPatchScalarField
         //  onto a new patch